//Set working directory (CHANGE)
//cd "YOUR DIRECTORY"


////////////////////////
//Media data analysis
////////////////////////


//Load media data
use "./Data/media_ecofin_6months.dta", clear


//Overall number of articles per country - mentioned in footnote 8 in the paper
sum Austria Germany Ireland Italy UK Malta Netherlands France Spain

//Calculate z-score by country
egen MEDIAAustria = std(Austria)
egen MEDIAGermany = std(Germany)
egen MEDIAIreland = std(Ireland)
egen MEDIAUK = std(UK)
egen MEDIAMalta = std(Malta)
egen MEDIAFrance = std(France)
egen MEDIANetherlands = std(Netherlands)
egen MEDIASpain = std(Spain)
egen MEDIAItaly = std(Italy)

//Create single categorical variable for all packages
gen package_cat = .
replace package_cat = 1 if ftt_package == 1
replace package_cat = 2 if budget_package == 1
replace package_cat = 3 if banking_package == 1
replace package_cat = 4 if tax_package == 1
replace package_cat = 5 if efsi_package == 1
label define package_cat 1 "Financial transaction tax" 2 "Budget" 3 "Banking union" 4 "Tax issues" 5 "EFSI"
label values package_cat package_cat

//Create Table A1 in the supplemental material
egen MEAN = rowmean(Austria France Germany Ireland Italy Malta Netherlands Spain UK)
estpost tabstat Austria France Germany Ireland Italy Malta Netherlands Spain UK MEAN, by(package_cat) statistics(mean) column(statistics) listwise
esttab using "./Results/Table_A1.rtf", replace main(mean) cells("mean(fmt(1))")  nostar unstack noobs nonote nomtitle nonumber

//Reshape
reshape long MEDIA pol_, i(id_debate) j(country) string
encode country, gen(country_enc)
rename pol_ politicization

//Investigate where packages are salient
tabstat politicization if ftt_package == 1, by(country)
tabstat politicization if banking_package == 1, by(country)
tabstat politicization if budget_package == 1, by(country)
tabstat politicization if efsi_package == 1, by(country)
tabstat politicization if tax_package == 1, by(country)

//Plot Figure 1 in the paper - without Malta
gen aux = 0.5
twoway (line MEDIA date_debate if country == "Austria") (line MEDIA date_debate if country == "France") (line MEDIA date_debate if country == "Germany")(line MEDIA date_debate if country == "Ireland") (line MEDIA date_debate if country == "Italy") (line MEDIA date_debate if country == "Netherlands") (line MEDIA date_debate if country == "Spain") (line MEDIA date_debate if country == "UK") (spike aux date_debate), by(package_cat, note("")) scheme(lean2) xtitle("") ytitle("Media coverage (z-score)") note("") xlabel(, angle(horizontal)) legend(order(1 2 3 4 5 6 7 8) label(1 "Austria") label(2 "France") label(3 "Germany") label(4 "Ireland") label(5 "Italy") label(6 "Netherlands") label(7 "Spain") label(8 "UK") label(9 "") rows(2)) xlab(18628 "2011" 19359 "2013" 20089 "2015") yline(0, lcolor(black) lwidth(vthin)) 
graph save "./Results/Figure_1.gph", replace
graph export "./Results/Figure_1.png", height(2000) replace
drop aux



///////////////////////////////
//Contestation in voting data
///////////////////////////////


//Load voting data
use "./Data/contestation_in_votes.dta", replace

//Generate dependent variables
gen opposition_vote = .
replace opposition_vote = 0 if Vote == "Yes"
replace opposition_vote = 1 if Vote == "No"
replace opposition_vote = 1 if Vote == "Abstain"

//Collapse to level of files
collapse opposition_vote (firstnm) package_cat, by(InterinstitutionalCode Actor)

//Last column of Table 1 in the paper - calculate number of opposition votes per package and on average
tab opposition_vote package_cat, column 



////////////////////////////////////////
//Contestation in public deliberations
////////////////////////////////////////


//Load contestation data for public deliberations
use "./Data/contestation_in_debates.dta", clear

//Table 1 in the paper - calculate overall disapproval rate 
egen participations = sum(no_govs) 
egen disapprovals = sum(no_disapproval) 
dis disapprovals/participations

//Table 1 in the paper - compare disapproval across packages 
egen interventions_per_package = sum(no_govs), by(package_cat)
egen disapproval_per_package = sum(no_disapproval), by(package_cat)
gen perc_diceu = disapproval_per_package / interventions_per_package
tabstat perc_diceu, by(package_cat) columns(variables)

//Table 1 in the paper - show level of disapproval by negotiation stage
egen interventions_per_stage = sum(no_govs), by(negotiation_stage)
egen disapproval_per_stage = sum(no_disapproval), by(negotiation_stage)
gen perc_diceu_stage = disapproval_per_stage / interventions_per_stage
tabstat perc_diceu_stage, by(negotiation_stage) columns(variables)

//Table 1 in the paper - show level of disapproval by negotiation stage and legislative package 
egen interventions_per_stage2 = sum(no_govs), by(negotiation_stage package_cat)
egen disapproval_per_stage2 = sum(no_disapproval), by(negotiation_stage package_cat)
gen perc_diceu_stage2 = disapproval_per_stage2 / interventions_per_stage2
sort package_cat
by package_cat: tabstat perc_diceu_stage2, by(negotiation_stage) columns(variables)

//Show number of debates by negotiation stage and legislative package
//- reported in the paper in section "Measuring government positions and contestation in the Council"
tab negotiation_stage

//Time spent on legislative packages, can be calculated by hand
//79% of all ECOFIN time - mentioned in the paper in section "Data and operationalisation"
tabstat debate_length, by(package_cat)
tab package_cat
sum debate_length



/////////////////
//Main analyses
/////////////////


//Load dataset
use "./Data/main_analyses_contestation.dta", clear

//Clarke test reported in section 7) of the supplemental material
tab negotiation_stage, gen(decision)

program mynormal_lf
        version 11.1
        args lnf mu lnsigma
        quietly replace `lnf' = ln(normalden($ML_y1,`mu', exp(`lnsigma')))
end

ml model lf  mynormal_lf  (approval = public_opinion_static politicization pol_opinion_static gov_planeco_cmp_static gov_eu_cmp_static eu_cont_gdp unemployment inflation population decision2 decision3) (lnsigma:)
ml max, nolog
predict double xb_reg
gen double lnf_reg = ln(normalden(approval, xb_reg, exp([lnsigma]_b[_cons])))

ml model lf  mynormal_lf  (approval = public_opinion_static_lead politicization pol_opinion_static_lead gov_planeco_cmp_static gov_eu_cmp_static eu_cont_gdp unemployment inflation population decision2 decision3) (lnsigma:)
ml max, nolog
predict double xb_reg_eu
gen double lnf_reg_eu = ln(normalden(approval, xb_reg_eu, exp([lnsigma]_b[_cons])))

gen diff = lnf_reg - lnf_reg_eu
kdensity diff if e(sample), normal scheme(lean2) title("") xtitle("Differences in log-likelihoods")
//Distribution is leptokurtic

signtest lnf_reg = lnf_reg_eu if e(sample) == 1
program drop mynormal_lf
drop lnf* xb* diff


//Brant test of violations of the parallel regression assumption, mentioned in section 6) of the supplemental material
ologit approval public_opinion_static pol_opinion_static politicization gov_planeco_cmp_static gov_eu_cmp_static eu_cont_gdp unemployment inflation population i.negotiation_stage
brant, detail

//Plot Figures A1 and A2 in the supplemental material - raw data relationships
label define politicization 0 "{bf:Low salience legislative package}" 1 "{bf:High salience legislative package}"
label values politicization politicization
twoway (scatter approval public_opinion_static) (lfit approval public_opinion_static), by(politicization, note("")) scheme(lean2) xtitle("Public opposition" "(z-score)") ytitle("Governmental disapproval in Council") legend(label(1 "Observations") label(2 "Linear regression line") rows(1))
graph save "./Results/Figure_A1.gph", replace
graph export "./Results/Figure_A1.png", replace height(2000)

twoway (scatter approval public_opinion_static) (lfit approval public_opinion_static), by(package_cat, note("") rows(3) iscale(*0.8)) scheme(lean2) xtitle("Public opposition" "(z-score)", size(small)) ytitle("Governmental disapproval in Council", size(small)) legend(size(*0.7) label(1 "Observations") label(2 "Linear regression line") rows(1))
graph display, ysize(7) xsize(7)
graph save "./Results/Figure_A2.gph", replace
graph export "./Results/Figure_A2.png", replace height(2000)


//Main analyses without MI and without controls - Table A3 in the supplemental material
//"Pooled model"
mixed approval politicization##c.public_opinion_static || _all: R.id_debate || _all: R.country
outreg using "./Results/Table_A3.doc", replace starlevels(5 1) se

//Plot Figure A3 in the supplemental material
margins, at(public_opinion_static = (-1.5 (0.15) 1.5) politicization = (0 1))
marginsplot, by(politicization, label("{bf:Low salience legislative package}" "{bf:High salience legislative package}")) xlab(-1.5 -1 -0.5 0 0.5 1 1.5) scheme(lean2) recast(line) recastci(rline) ylabel(,glcolor(none) glwidth(vvthin)) ciopts(lpattern(longdash)) plot1opts(mcolor(gs10) lcolor(gs5)) xtitle("Public opposition" "(z-score)") ytitle("Governmental disapproval in Council") byopts(title("")) 
graph save "./Results/Figure_A3.gph", replace
graph export "./Results/Figure_A3.png", replace height(2000)

//"FTT" model
mixed approval pref_ftt_static if ftt_package == 1 || country:
outreg using "./Results/Table_A3.doc", merge starlevels(5 1) se

//"EU budget" model
mixed approval pref_budget_static if budget_package == 1 || country:
outreg using "./Results/Table_A3.doc", merge starlevels(5 1) se

//"Banking union" model
mixed approval pref_tax_bank_static if banking_package == 1 || country:
outreg using "./Results/Table_A3.doc", merge starlevels(5 1) se

//"Tax issues" model
mixed approval pref_tax_rules_static if tax_package == 1 || country:
outreg using "./Results/Table_A3.doc", merge starlevels(5 1) se

//"EFSI" model
mixed approval pref_efsi_static if efsi_package == 1 || country:
outreg using "./Results/Table_A3.doc", merge starlevels(5 1) se


//Plot Figures A4.1 and A4.2 - raw data relationships by country
encode actor, gen(actor_enc)
twoway (scatter approval public_opinion_static) (lfit approval public_opinion_static) if actor_enc <= 15, by(actor, note("") rows(5)) scheme(lean2) xtitle("Public opposition" "(z-score)", size(small)) ytitle("Governmental disapproval in Council", size(small)) legend(size(*0.7) label(1 "Observations") label(2 "Linear regression line") rows(1))
graph display, ysize(10) xsize(7)
graph save "./Results/Figure_A4_1.gph", replace
graph export "./Results/Figure_A4_1.png", replace height(2000)

twoway (scatter approval public_opinion_static) (lfit approval public_opinion_static) if actor_enc > 15, by(actor, note("") rows(5)) scheme(lean2) xtitle("Public opposition" "(z-score)", size(small)) ytitle("Governmental disapproval in Council", size(small)) legend(size(*0.7) label(1 "Observations") label(2 "Linear regression line") rows(1))
graph display, ysize(10) xsize(7)
graph save "./Results/Figure_A4_2.gph", replace
graph export "./Results/Figure_A4_2.png", replace height(2000)


//Estimate models in Table A5 - robustness checks (part I)

//Model R1: Main analyses with binary country-specific measure of media attention
mixed approval politicization_by_country##c.public_opinion_static gov_planeco_cmp_static gov_eu_cmp_static eu_cont_gdp unemployment inflation population i.negotiation_stage || _all: R.id_debate || _all: R.country
outreg using "./Results/Table_A5_1.doc", replace starlevels(5 1) se

//Model R2: Operationalising salience through DK/refusal responses
mixed approval c.opinion_salience_static##c.public_opinion_static gov_planeco_cmp_static gov_eu_cmp_static eu_cont_gdp unemployment inflation population i.negotiation_stage || _all: R.id_debate || _all: R.country
outreg using "./Results/Table_A5_1.doc", merge starlevels(5 1) se


//Test whether public opinion effect varies by negotiation stage
mixed approval i.negotiation_stage##c.public_opinion_static gov_planeco_cmp_static gov_eu_cmp_static eu_cont_gdp unemployment inflation population i.negotiation_stage || _all: R.id_debate || _all: R.country
//Does not vary


//Descriptive statistics for main variables
//Generate auxiliary variables
gen pref_tax_bank_static_aux = pref_tax_bank_static if banking_package == 1
gen pref_ftt_static_aux = pref_ftt_static if ftt_package == 1
gen pref_tax_rules_static_aux = pref_tax_rules_static if tax_package == 1
gen pref_budget_static_aux = pref_budget_static if budget_package == 1
gen pref_efsi_static_aux = pref_efsi_static if efsi_package == 1

//Create Table A2 in the supplemental material
estpost sum approval pref_tax_bank_static_aux pref_tax_rules_static_aux pref_ftt_static_aux pref_budget_static_aux pref_efsi_static_aux public_opinion_static politicization gov_planeco_cmp_static gov_eu_cmp_static eu_cont_gdp unemployment inflation population decision1 decision2 decision3
esttab using "./Results/Table_A2.rtf", replace cells("mean(fmt(2)) sd(fmt(2)) min(fmt(2)) max(fmt(2)) count(fmt(0))") varlabels(`e(labels)') nomtitle nonumber label
drop *_aux


//Sort and prepare for multiple imputation
sort id_debate country
keep negotiation_stage ftt_package budget_package banking_package tax_package efsi_package pref_tax_bank_ipol pref_tax_rules_ipol pref_ftt_ipol pref_budget_ipol pref_efsi_ipol pref_tax_bank_static pref_tax_rules_static pref_ftt_static pref_budget_static pref_efsi_static pref_tax_bank_lag6m pref_tax_rules_lag6m pref_ftt_lag6m pref_budget_lag6m pref_efsi_lag6m public_opinion_lag6m public_opinion public_opinion_static pol_opinion_static pol2_opinion_static pol_opinion pol_opinion_lag6m gov_planeco_cmp_static gov_eu_cmp_static approval eu_cont_gdp unemployment inflation population politicization politicization2 family_gov* lrs_ipol lrs_lag6m image_ipol image_lag6m id_debate country

//Show amount of missing data for main model
mdesc approval public_opinion_static politicization pol_opinion_static gov_planeco_cmp_static gov_eu_cmp_static eu_cont_gdp unemployment inflation population negotiation_stage


//Save before imputation 
save "./Data/before_imputations.dta", replace



///////////////////////
//Pooled models (MI)
///////////////////////


//Imputes by politicization

//Perform multiple imputation
xtset country
mi set flong
mi register imputed public_opinion public_opinion_static public_opinion_lag6m gov_planeco_cmp_static gov_eu_cmp_static
set seed 14534645
mi impute chained (pmm, knn(5)) public_opinion public_opinion_static public_opinion_lag6m gov_planeco_cmp_static gov_eu_cmp_static = approval eu_cont_gdp unemployment inflation population politicization2 family_gov* lrs_ipol lrs_lag6m image_ipol image_lag6m i.negotiation_stage i.id_debate i.country, by(politicization) add(30) burnin(100) force
//ALL VALUES IMPUTED - but eu_cont_gdp with a single missing value was not included in model, hence 751 complete observations

//Save
save "./Data/imputed_pooled.dta", replace


//Estimate models in Table 2 in the paper

//Model 1: Without interaction term, debate & country REs
mi estimate, post: mixed approval public_opinion_static gov_planeco_cmp_static gov_eu_cmp_static eu_cont_gdp unemployment inflation population i.negotiation_stage || _all: R.id_debate || _all: R.country
outreg using "./Results/Table_2.doc", replace starlevels(5 1) se

//Model 2: With interaction term, debate & country REs
mi estimate, post saving("./Results/miest", replace): mixed approval politicization##c.public_opinion_static gov_planeco_cmp_static gov_eu_cmp_static eu_cont_gdp unemployment inflation population i.negotiation_stage || _all: R.id_debate || _all: R.country
outreg using "./Results/Table_2.doc", merge starlevels(5 1) se

//Plot Figure 2 in the paper
mimrgns, at(public_opinion_static = (-1.5 (0.15) 1.5) politicization = (0 1)) cmdmargins
marginsplot, by(politicization, label("{bf:Low salience legislative package}" "{bf:High salience legislative package}")) xlab(-1.5 -1 -0.5 0 0.5 1 1.5) scheme(lean2) recast(line) recastci(rline) ylabel(,glcolor(none) glwidth(vvthin)) ciopts(lpattern(longdash)) plot1opts(mcolor(gs10) lcolor(gs5)) xtitle("Public opposition" "(z-score)") ytitle("Governmental disapproval in Council") byopts(title("")) 
graph save "./Results/Figure_2.gph", replace
graph export "./Results/Figure_2.png", replace height(2000)

//Model 3: With interaction term, debate RE & country FEs
mi estimate, post: mixed approval politicization##c.public_opinion_static gov_planeco_cmp_static gov_eu_cmp_static eu_cont_gdp unemployment inflation i.country || _all: R.id_debate
outreg using "./Results/Table_2.doc", merge starlevels(5 1) se



////////////////////////
//Separate models (MI)
////////////////////////


//Use JAV ("just another variable") approach to interactions

//Perform multiple imputation
use "./Data/before_imputations.dta", clear
xtset country
mi set flong
mi register imputed pref_tax_bank_ipol pref_tax_rules_ipol pref_ftt_ipol pref_budget_ipol pref_efsi_ipol pref_tax_bank_static pref_tax_rules_static pref_ftt_static pref_budget_static pref_efsi_static pref_tax_bank_lag6m pref_tax_rules_lag6m pref_ftt_lag6m pref_budget_lag6m pref_efsi_lag6m public_opinion public_opinion_static public_opinion_lag6m pol_opinion_static pol_opinion pol2_opinion_static pol_opinion_lag6m gov_planeco_cmp_static gov_eu_cmp_static
set seed 7879234
mi impute chained (pmm, knn(5)) pref_tax_bank_ipol pref_tax_rules_ipol pref_ftt_ipol pref_budget_ipol pref_efsi_ipol pref_tax_bank_static pref_tax_rules_static pref_ftt_static pref_budget_static pref_efsi_static pref_tax_bank_lag6m pref_tax_rules_lag6m pref_ftt_lag6m pref_budget_lag6m pref_efsi_lag6m public_opinion public_opinion_static public_opinion_lag6m pol_opinion_static pol_opinion pol2_opinion_static pol_opinion_lag6m gov_planeco_cmp_static gov_eu_cmp_static = approval eu_cont_gdp unemployment inflation population politicization politicization2 family_gov* lrs_ipol lrs_lag6m image_ipol image_lag6m i.negotiation_stage i.id_debate i.country, add(30) burnin(100) force

//Save
save "./Data/imputed_separately_rc.dta", replace


//Estimate models in Table A4 in the supplemental material - each legislative package separately
//with specific selection of controls for each package

//"FTT"
mi estimate, post saving("./Results/miest", replace): mixed approval pref_ftt_static gov_planeco_cmp_static gov_eu_cmp_static eu_cont_gdp unemployment inflation population if ftt_package == 1 || country:
outreg using "./Results/Table_A4.doc", replace starlevels(10 5 1) se
sum pref_ftt_static, detail
mimrgns, at(pref_ftt_static = (1.5 (0.15) 3)) cmdmargins
marginsplot, xlab(1.5 1.8 2.1 2.4 2.7 3) scheme(lean2) recast(line) recastci(rline) ylabel(,glcolor(none) glwidth(vvthin)) ciopts(lpattern(longdash)) plot1opts(mcolor(gs10) lcolor(gs5)) xtitle("Public opposition to financial transaction tax") ytitle("Governmental disapproval in Council") title("{bf:Financial transaction tax}")
graph save "./Results/ftt-opinion.gph", replace
graph export "./Results/ftt-opinion.png", replace

//"EU budget"
mi estimate, post saving("./Results/miest", replace): mixed approval pref_budget_static gov_planeco_cmp_static gov_eu_cmp_static eu_cont_gdp unemployment inflation if budget_package == 1 || country:
outreg using "./Results/Table_A4.doc", merge starlevels(10 5 1) se
sum pref_budget_static, detail
mimrgns, at(pref_budget_static = (0.3 (0.05) 0.8)) cmdmargins
marginsplot, xlab(0.3 0.4 0.5 0.6 0.7 0.8) yscale(axis(1) alt off) scheme(lean2) recast(line) recastci(rline) ylabel(,glcolor(none) glwidth(vvthin)) ciopts(lpattern(longdash)) plot1opts(mcolor(gs10) lcolor(gs5)) xtitle("Public opposition to larger budgets") ytitle("Governmental disapproval in Council") title("{bf:EU budget}")
graph save "./Results/budget-opinion.gph", replace
graph export "./Results/budget-opinion.png", replace

//"Banking union"
mi estimate, post saving("./Results/miest", replace): mixed approval pref_tax_bank_static gov_planeco_cmp_static gov_eu_cmp_static unemployment inflation population if banking_package == 1 || country:
outreg using "./Results/Table_A4.doc", merge starlevels(10 5 1) se
sum pref_tax_bank_static, detail
mimrgns, at(pref_tax_bank_static = (1.2 (0.1) 2.2)) cmdmargins
marginsplot, xlab(1.2 1.4 1.6 1.8 2.0 2.2) yscale(axis(1) alt off) scheme(lean2) recast(line) recastci(rline) ylabel(,glcolor(none) glwidth(vvthin)) ciopts(lpattern(longdash)) plot1opts(mcolor(gs10) lcolor(gs5)) xtitle("Public opposition to bank tax") ytitle("Governmental disapproval in Council") title("{bf:Banking union}")
graph save "./Results/banking-opinion.gph", replace
graph export "./Results/banking-opinion.png", replace

//"Tax issues"
mi estimate, post saving("./Results/miest", replace): mixed approval pref_tax_rules_static gov_planeco_cmp_static gov_eu_cmp_static unemployment inflation population if tax_package == 1 || country:
outreg using "./Results/Table_A4.doc", merge starlevels(10 5 1) se
sum pref_tax_rules_static, detail
mimrgns, at(pref_tax_rules_static = (1.2 (0.1) 2.0)) cmdmargins
marginsplot, xlab(1.2 1.4 1.6 1.8 2.0) scheme(lean2) recast(line) recastci(rline) ylabel(,glcolor(none) glwidth(vvthin)) ciopts(lpattern(longdash)) plot1opts(mcolor(gs10) lcolor(gs5)) xtitle("Public opposition to new taxation rules") ytitle("Governmental disapproval in Council") title("{bf:Tax issues}")
graph save "./Results/tax-opinion.gph", replace
graph export "./Results/tax-opinion.png", replace

//"EFSI"
mi estimate, post saving("./Results/miest", replace): mixed approval pref_efsi_static gov_planeco_cmp_static gov_eu_cmp_static eu_cont_gdp unemployment inflation if efsi_package == 1 || country:
outreg using "./Results/Table_A4.doc", merge starlevels(10 5 1) se
sum pref_efsi_static, detail
mimrgns, at(pref_efsi_static = (1.6 (0.1) 2.6)) cmdmargins
marginsplot, xlab(1.6 1.8 2.0 2.2 2.4 2.6) yscale(axis(1) alt off) scheme(lean2) recast(line) recastci(rline) ylabel(,glcolor(none) glwidth(vvthin)) ciopts(lpattern(longdash)) plot1opts(mcolor(gs10) lcolor(gs5)) xtitle("Public opposition to funded investments at EU level") ytitle("Governmental disapproval in Council") title("{bf:European Fund for Strategic Investments}")
graph save "./Results/efsi-opinion.gph", replace
graph export "./Results/efsi-opinion.png", replace

//Plot Figure 3 in the paper
graph combine "./Results/ftt-opinion.gph" "./Results/budget-opinion.gph" "./Results/banking-opinion.gph" "./Results/tax-opinion.gph" "./Results/efsi-opinion.gph", scheme(lean2) altshrink row(2) ycommon
graph save "./Results/Figure_3.gph", replace
graph export "./Results/Figure_3.png", replace height(2000)



//////////////////////////
//Robustness checks (MI)
//////////////////////////


//Estimate models in Table A5 in the supplemental material (part II)

//Model R3: Alternative coding of salience indicator (tax issues salient)
mi estimate, post: mixed approval public_opinion_static politicization2 pol2_opinion_static gov_planeco_cmp_static gov_eu_cmp_static eu_cont_gdp unemployment inflation population i.negotiation_stage || _all: R.id_debate || _all: R.country
outreg using "./Results/Table_A5_2.doc", replace starlevels(5 1) se

//Model R4: Country and debate fixed effects (politicization indicator omitted)
mi estimate, post: reg approval public_opinion_static pol_opinion_static gov_planeco_cmp_static gov_eu_cmp_static eu_cont_gdp unemployment inflation i.country i.id_debate
outreg using "./Results/Table_A5_2.doc", merge starlevels(5 1) se

//Model R5: Ordered logit
mi estimate, post cmdok: meologit approval public_opinion_static politicization pol_opinion_static gov_planeco_cmp_static gov_eu_cmp_static eu_cont_gdp unemployment inflation i.negotiation_stage i.country ||  id_debate:
outreg using "./Results/Table_A5_2.doc", merge starlevels(5 1) se

//Model R6: Without imputations
mixed approval public_opinion_static politicization pol_opinion_static gov_planeco_cmp_static gov_eu_cmp_static eu_cont_gdp unemployment inflation population i.negotiation_stage if _mi_m == 0  || _all: R.id_debate || _all: R.country
outreg using "./Results/Table_A5_2.doc", merge starlevels(5 1) se

//Model R7: Opinion as 6-month lag
mi estimate, post: mixed approval public_opinion_lag6m politicization pol_opinion_lag6m gov_planeco_cmp_static gov_eu_cmp_static eu_cont_gdp unemployment inflation population i.negotiation_stage || _all: R.id_debate || _all: R.country
outreg using "./Results/Table_A5_2.doc", merge starlevels(5 1) se

//Model R8: Current opinion
mi estimate, post: mixed approval public_opinion politicization pol_opinion gov_planeco_cmp_static gov_eu_cmp_static eu_cont_gdp unemployment inflation population i.negotiation_stage || _all: R.id_debate || _all: R.country
outreg using "./Results/Table_A5_2.doc", merge starlevels(5 1) se


//Estimate models in Table A6.1 in the supplemental material - each legislative package separately using 6-month lag of opinion

//"FTT"
mi estimate, post: mixed approval pref_ftt_lag6m gov_planeco_cmp_static gov_eu_cmp_static eu_cont_gdp unemployment inflation population if ftt_package == 1 || country:
outreg using "./Results/Table_A6_1.doc", replace starlevels(10 5 1) se

//"EU budget"
mi estimate, post: mixed approval pref_budget_lag6m gov_planeco_cmp_static gov_eu_cmp_static eu_cont_gdp unemployment inflation if budget_package == 1 || country:
outreg using "./Results/Table_A6_1.doc", merge starlevels(10 5 1) se

//"Banking union"
mi estimate, post: mixed approval pref_tax_bank_lag6m gov_planeco_cmp_static gov_eu_cmp_static unemployment inflation population if banking_package == 1 || country:
outreg using "./Results/Table_A6_1.doc", merge starlevels(10 5 1) se

//"Tax issues"
mi estimate, post: mixed approval pref_tax_rules_lag6m gov_planeco_cmp_static gov_eu_cmp_static unemployment inflation population if tax_package == 1 || country:
outreg using "./Results/Table_A6_1.doc", merge starlevels(10 5 1) se

//"EFSI"
mi estimate, post: mixed approval pref_efsi_lag6m gov_planeco_cmp_static gov_eu_cmp_static eu_cont_gdp unemployment inflation if efsi_package == 1 || country:
outreg using "./Results/Table_A6_1.doc", merge starlevels(10 5 1) se


//Estimate models in Table A6.2 in the supplemental material - each legislative package separately using current opinion

//"FTT"
mi estimate, post: mixed approval pref_ftt_ipol gov_planeco_cmp_static gov_eu_cmp_static eu_cont_gdp unemployment inflation population if ftt_package == 1 || country:
outreg using "./Results/Table_A6_2.doc", replace starlevels(10 5 1) se

//"EU budget"
mi estimate, post: mixed approval pref_budget_ipol gov_planeco_cmp_static gov_eu_cmp_static eu_cont_gdp unemployment inflation if budget_package == 1 || country:
outreg using "./Results/Table_A6_2.doc", merge starlevels(10 5 1) se

//"Banking union"
mi estimate, post: mixed approval pref_tax_bank_ipol gov_planeco_cmp_static gov_eu_cmp_static unemployment inflation population if banking_package == 1 || country:
outreg using "./Results/Table_A6_2.doc", merge starlevels(10 5 1) se

//"Tax issues"
mi estimate, post: mixed approval pref_tax_rules_ipol gov_planeco_cmp_static gov_eu_cmp_static unemployment inflation population if tax_package == 1 || country:
outreg using "./Results/Table_A6_2.doc", merge starlevels(10 5 1) se

//"EFSI"
mi estimate, post: mixed approval pref_efsi_ipol gov_planeco_cmp_static gov_eu_cmp_static eu_cont_gdp unemployment inflation if efsi_package == 1 || country:
outreg using "./Results/Table_A6_2.doc", merge starlevels(10 5 1) se
